@@ -1,9 +1,9 @@
 from django_codemod.constants import DJANGO_2_0, DJANGO_3_0
-from django_codemod.visitors.base import BaseSimpleFuncRenameTransformer
+from django_codemod.visitors.base import BaseFuncRenameTransformer
 
 
-class AbsPathTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils._os.abspathu``."""
+class AbsPathTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils._os.abspathu` by `os.path.abspath`."""
 
     deprecated_in = DJANGO_2_0
     removed_in = DJANGO_3_0
